Index: issm/trunk/packagers/macosx/package.sh
===================================================================
--- issm/trunk/packagers/macosx/package.sh	(revision 23398)
+++ issm/trunk/packagers/macosx/package.sh	(revision 23403)
@@ -1,5 +1,7 @@
 #!/bin/bash
 
-TARBALL_NAME='issm-mac-static_build'
+MATLAB_PATH="/Applications/MATLAB_R2015b.app"
+PACKAGE="ISSM" # Name of directory to copy distributable files to
+TARBALL_NAME="issm-mac-static_build"
 TARBALL=$TARBALL_NAME.tar.gz
 
@@ -7,6 +9,6 @@
 echo "Cleaning up existing assets"
 cd $ISSM_DIR
-rm -rf trunk
-mkdir trunk
+rm -rf $PACKAGE
+mkdir $PACKAGE
 
 # Add/modify required binaries
@@ -31,11 +33,11 @@
 fi
 
 # Copy gmt to trunk
 # NOTE: The following assumes the precompiled version of gmt
 echo "Moving gmt to externalpackages"
 if [ -f $ISSM_DIR/externalpackages/gmt/install/bin/gmt ]; then
-	mkdir $ISSM_DIR/trunk/externalpackages
-	mkdir $ISSM_DIR/trunk/externalpackages/gmt
-	cp -a $ISSM_DIR/externalpackages/gmt/install/. $ISSM_DIR/trunk/externalpackages/gmt
+	mkdir $ISSM_DIR/$PACKAGE/externalpackages
+	mkdir $ISSM_DIR/$PACKAGE/externalpackages/gmt
+	cp -a $ISSM_DIR/externalpackages/gmt/install/. $ISSM_DIR/$PACKAGE/externalpackages/gmt
 else
 	echo "gmt not found"
@@ -45,5 +47,5 @@
 cd $ISSM_DIR/test/NightlyRun
 rm matlab.log
-/Applications/MATLAB_R2015b.app/bin/matlab -nodisplay -nojvm -nosplash -nodesktop -r "try, addpath $ISSM_DIR/bin $ISSM_DIR/lib; runme('id',101);exit; catch me,fprintf('%s',getReport(me)); exit; end" -logfile matlab.log
+$MATLAB_PATH/bin/matlab -nodisplay -nojvm -nosplash -nodesktop -r "try, addpath $ISSM_DIR/bin $ISSM_DIR/lib; runme('id',101);exit; catch me,fprintf('%s',getReport(me)); exit; end" -logfile matlab.log
 
 if [[ $(cat matlab.log | grep -c SUCCESS) -lt 10 ]]; then
@@ -57,15 +59,15 @@
 cd $ISSM_DIR
 rm -f $TARBALL
-cp -rf bin lib test examples scripts trunk/
+cp -rf bin lib test examples scripts $PACKAGE/
 
 # Create link to gmt from bin
 # NOTE: It is important that we are in the destination dir when sym linking so that the path is relative
-if [ -f $ISSM_DIR/trunk/externalpackages/gmt/bin/gmt ]; then
-	cd $ISSM_DIR/trunk/bin
+if [ -f $ISSM_DIR/$PACKAGE/externalpackages/gmt/bin/gmt ]; then
+	cd $ISSM_DIR/$PACKAGE/bin
 	ln -s ../externalpackages/gmt/bin/gmt ./gmt
 fi
 
 cd $ISSM_DIR
-tar -czf $TARBALL trunk
+tar -czf $TARBALL $PACKAGE
 ls -lah $TARBALL
 
@@ -31,11 +33,11 @@
 fi
 
-# Copy gmt to trunk
+# Copy gmt to package
 # NOTE: The following assumes the precompiled version of gmt
 echo "Moving gmt to externalpackages"
Index: issm/trunk/packagers/win10/package64.sh
===================================================================
--- issm/trunk/packagers/win10/package64.sh	(revision 23398)
+++ issm/trunk/packagers/win10/package64.sh	(revision 23403)
@@ -1,7 +1,8 @@
 #!/bin/bash
 
+MATLAB_PATH="/cygdrive/c/Programs/MATLAB/R2015a"
+PACKAGE="ISSM" # Name of directory to copy distributable files to
 TARBALL_NAME='ISSM-Win10-64'
 TARBALL=$TARBALL_NAME.tar.gz
-MATLAB_PATH="/cygdrive/c/Programs/MATLAB/R2015a"
 
 # Source Windows environment
@@ -11,6 +12,6 @@
 echo "Cleaning up existing assets"
 cd $ISSM_DIR
-rm -rf trunk
-mkdir trunk
+rm -rf $PACKAGE
+mkdir $PACKAGE
 
 # Add/modify required binaries
@@ -26,16 +27,16 @@
 echo "Copying gmsh to bin"
 if [ -f ../externalpackages/gmsh/install/gmsh.exe ]; then
-	cp ../externalpackages/gmsh/install/gmsh.exe .
+	cp ../externalpackages/gmsh/install/gmsh.exe ./gmsh
 else
 	echo "gmsh not found"
 fi
 
 # Copy gmt to trunk
 # NOTE: The following assumes the precompiled version of gmt
 echo "Moving gmt to externalpackages"
 if [ -f $ISSM_DIR/externalpackages/gmt/install/bin/gmt ]; then
-	mkdir $ISSM_DIR/trunk/externalpackages
-	mkdir $ISSM_DIR/trunk/externalpackages/gmt
-	cp -a $ISSM_DIR/externalpackages/gmt/install/. $ISSM_DIR/trunk/externalpackages/gmt
+	mkdir $ISSM_DIR/$PACKAGE/externalpackages
+	mkdir $ISSM_DIR/$PACKAGE/externalpackages/gmt
+	cp -a $ISSM_DIR/externalpackages/gmt/install $ISSM_DIR/$PACKAGE/externalpackages/gmt/install
 else
 	echo "gmt not found"
@@ -67,15 +68,15 @@
 cd $ISSM_DIR
 rm -f $TARBALL
-cp -rf bin lib test examples scripts trunk/
+cp -rf bin lib test examples scripts $PACKAGE/
 
 # Create link to gmt from bin
 # NOTE: It is important that we are in the destination dir when sym linking so that the path is relative
-if [ -f $ISSM_DIR/trunk/externalpackages/gmt/bin/gmt ]; then
-	cd $ISSM_DIR/trunk/bin
-	ln -s ../externalpackages/gmt/bin/gmt.exe ./gmt
+if [ -f $ISSM_DIR/$PACKAGE/externalpackages/gmt/bin/gmt ]; then
+	cd $ISSM_DIR/$PACKAGE/bin
+	ln -s ../externalpackages/gmt/bin/gmt.exe ./gmt.exe
 fi
 
 cd $ISSM_DIR
-tar -czf $TARBALL trunk
+tar -czf $TARBALL $PACKAGE
 ls -lah $TARBALL
 
@@ -26,16 +27,16 @@
 fi
 
-# Copy gmt to trunk
+# Copy gmt to package
 # NOTE: The following assumes the precompiled version of gmt
 echo "Moving gmt to externalpackages"
